From: Linus Torvalds Date: Sun, 12 Feb 2006 07:05:06 GMT Subject: Re: [PATCH] binary-tree-based objects. Message-ID: In-Reply-To: On Sat, 11 Feb 2006, Linus Torvalds wrote: > > Before: > real 0m41.322s user 0m40.612s sys 0m0.492s > After: > real 0m22.542s user 0m22.080s sys 0m0.448s Johannes: real 0m13.814s user 0m13.492s sys 0m0.296s > And just so you wouldn't think that all my machines are slow.. > > Before: > real 0m28.645s user 0m28.366s sys 0m0.280s > After: > real 0m16.566s user 0m16.373s sys 0m0.196s Johannes: real 0m10.239s user 0m10.029s sys 0m0.208s So the hashing thing is indeed the clear winner. Make it so. Linus